<a href="https://pypi.org/project/spacemake/">
   <img src="https://img.shields.io/pypi/v/spacemake.svg" / ></a>
   
<a href="https://spacemake.readthedocs.io/">
   <img src="https://readthedocs.org/projects/spacemake/badge/?version=latest" / ></a>
   
 <a href="https://pepy.tech/project/spacemake">
   <img src="https://pepy.tech/badge/spacemake" / ></a>

# spacemake: processing and analysis of large-scale spatial transcriptomics data

<img src="https://raw.githubusercontent.com/rajewsky-lab/spacemake/master/docs/graphical_abstract_twitter.png" width="500" />

Documentation can be found [here](https://spacemake.readthedocs.io/en/latest/).

